==> certmanager-model-v1alpha2-6.7.1-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEIssuerBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEIssuerBuilder extends ACMEIssuerFluentImpl<ACMEIssuerBuilder> implements VisitableBuilder<ACMEIssuer,ACMEIssuerBuilder>{
  public ACMEIssuerBuilder() {
    this(false);
  }
  public ACMEIssuerBuilder(Boolean validationEnabled) {
    this(new ACMEIssuer(), validationEnabled);
  }
  public ACMEIssuerBuilder(ACMEIssuerFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEIssuerBuilder(ACMEIssuerFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEIssuer(), validationEnabled);
  }
  public ACMEIssuerBuilder(ACMEIssuerFluent<?> fluent,ACMEIssuer instance) {
    this(fluent, instance, false);
  }
  public ACMEIssuerBuilder(ACMEIssuerFluent<?> fluent,ACMEIssuer instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withDisableAccountKeyGeneration(instance.getDisableAccountKeyGeneration());
      fluent.withEmail(instance.getEmail());
      fluent.withEnableDurationFeature(instance.getEnableDurationFeature());
      fluent.withExternalAccountBinding(instance.getExternalAccountBinding());
      fluent.withPreferredChain(instance.getPreferredChain());
      fluent.withPrivateKeySecretRef(instance.getPrivateKeySecretRef());
      fluent.withServer(instance.getServer());
      fluent.withSkipTLSVerify(instance.getSkipTLSVerify());
      fluent.withSolvers(instance.getSolvers());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEIssuerBuilder(ACMEIssuer instance) {
    this(instance,false);
  }
  public ACMEIssuerBuilder(ACMEIssuer instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withDisableAccountKeyGeneration(instance.getDisableAccountKeyGeneration());
      this.withEmail(instance.getEmail());
      this.withEnableDurationFeature(instance.getEnableDurationFeature());
      this.withExternalAccountBinding(instance.getExternalAccountBinding());
      this.withPreferredChain(instance.getPreferredChain());
      this.withPrivateKeySecretRef(instance.getPrivateKeySecretRef());
      this.withServer(instance.getServer());
      this.withSkipTLSVerify(instance.getSkipTLSVerify());
      this.withSolvers(instance.getSolvers());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEIssuerFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEIssuer build() {
    ACMEIssuer buildable = new ACMEIssuer(fluent.getDisableAccountKeyGeneration(),fluent.getEmail(),fluent.getEnableDurationFeature(),fluent.getExternalAccountBinding(),fluent.getPreferredChain(),fluent.getPrivateKeySecretRef(),fluent.getServer(),fluent.getSkipTLSVerify(),fluent.getSolvers());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha2-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEIssuerBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEIssuerBuilder extends ACMEIssuerFluent<ACMEIssuerBuilder> implements VisitableBuilder<ACMEIssuer,ACMEIssuerBuilder>{
  public ACMEIssuerBuilder() {
    this(false);
  }
  public ACMEIssuerBuilder(Boolean validationEnabled) {
    this(new ACMEIssuer(), validationEnabled);
  }
  public ACMEIssuerBuilder(ACMEIssuerFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEIssuerBuilder(ACMEIssuerFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEIssuer(), validationEnabled);
  }
  public ACMEIssuerBuilder(ACMEIssuerFluent<?> fluent,ACMEIssuer instance) {
    this(fluent, instance, false);
  }
  public ACMEIssuerBuilder(ACMEIssuerFluent<?> fluent,ACMEIssuer instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ACMEIssuer());

    if (instance != null) {
      fluent.withDisableAccountKeyGeneration(instance.getDisableAccountKeyGeneration());
      fluent.withEmail(instance.getEmail());
      fluent.withEnableDurationFeature(instance.getEnableDurationFeature());
      fluent.withExternalAccountBinding(instance.getExternalAccountBinding());
      fluent.withPreferredChain(instance.getPreferredChain());
      fluent.withPrivateKeySecretRef(instance.getPrivateKeySecretRef());
      fluent.withServer(instance.getServer());
      fluent.withSkipTLSVerify(instance.getSkipTLSVerify());
      fluent.withSolvers(instance.getSolvers());
      fluent.withDisableAccountKeyGeneration(instance.getDisableAccountKeyGeneration());
      fluent.withEmail(instance.getEmail());
      fluent.withEnableDurationFeature(instance.getEnableDurationFeature());
      fluent.withExternalAccountBinding(instance.getExternalAccountBinding());
      fluent.withPreferredChain(instance.getPreferredChain());
      fluent.withPrivateKeySecretRef(instance.getPrivateKeySecretRef());
      fluent.withServer(instance.getServer());
      fluent.withSkipTLSVerify(instance.getSkipTLSVerify());
      fluent.withSolvers(instance.getSolvers());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEIssuerBuilder(ACMEIssuer instance) {
    this(instance,false);
  }
  public ACMEIssuerBuilder(ACMEIssuer instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ACMEIssuer());

    if (instance != null) {
      this.withDisableAccountKeyGeneration(instance.getDisableAccountKeyGeneration());
      this.withEmail(instance.getEmail());
      this.withEnableDurationFeature(instance.getEnableDurationFeature());
      this.withExternalAccountBinding(instance.getExternalAccountBinding());
      this.withPreferredChain(instance.getPreferredChain());
      this.withPrivateKeySecretRef(instance.getPrivateKeySecretRef());
      this.withServer(instance.getServer());
      this.withSkipTLSVerify(instance.getSkipTLSVerify());
      this.withSolvers(instance.getSolvers());
      this.withDisableAccountKeyGeneration(instance.getDisableAccountKeyGeneration());
      this.withEmail(instance.getEmail());
      this.withEnableDurationFeature(instance.getEnableDurationFeature());
      this.withExternalAccountBinding(instance.getExternalAccountBinding());
      this.withPreferredChain(instance.getPreferredChain());
      this.withPrivateKeySecretRef(instance.getPrivateKeySecretRef());
      this.withServer(instance.getServer());
      this.withSkipTLSVerify(instance.getSkipTLSVerify());
      this.withSolvers(instance.getSolvers());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEIssuerFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEIssuer build() {
    ACMEIssuer buildable = new ACMEIssuer(fluent.getDisableAccountKeyGeneration(),fluent.getEmail(),fluent.getEnableDurationFeature(),fluent.buildExternalAccountBinding(),fluent.getPreferredChain(),fluent.buildPrivateKeySecretRef(),fluent.getServer(),fluent.getSkipTLSVerify(),fluent.buildSolvers());
    return buildable;
  }
  
}
